==> yahoi-0.1.0.tgz: package/src/lib/Server.js <==
import './conditional-babel-polyfill';
import express from 'express';
import readdir from 'readdir';
import bodyParser from 'body-parser';
import cookieParser from 'cookie-parser';
import compression from 'compression';
const ENVIRONMENT_PATH = "Environments/";
const ROUTERS_PATH = "Routing/";
const Controller_PATH = "Controller/";

import path from 'path';
import ErrorController from './../Controller/ErrorController';



export default class Server {
  
  constructor(props) {

    this.__props = props;
    this.__environment = this.loadEnvironment(props.env);
    this.__controller = this.loadController(props.env);


    // Default Error Controller
    let defaultErrorController =  new ErrorController({ app: this } );
    defaultErrorController.setViewDirectory(path.resolve(__dirname, '..', 'Views'));
    defaultErrorController.setProjectDirectory(path.resolve(__dirname, '..'));
    defaultErrorController.setComponentDirectory(path.resolve(__dirname, '..', 'Components'));
    defaultErrorController.setContainerDirectory(path.resolve(__dirname, '..', 'Containers'));
    this.__controller['__defaultErrorController'] = defaultErrorController;

    this.__routers = this.loadRouters(props.env);
    this.__expressApp = express();
    this.__expressApp.use(bodyParser.json())
    this.__expressApp.use(cookieParser())
   
    
   
    this.getController = this.getController.bind(this);

    this.__defaultRouter = new (this.__routers['Default'])({ app: this });

    if(typeof(process.env.NODE_ENV)!='undefined' && process.env.NODE_ENV=='development') {
      // Development
      let enableHmrMidWare = require('./dev/expressMiddleware.js');
      enableHmrMidWare(this, this.__expressApp);
    } else {     
      // Production
      this.__expressApp.use(compression());
    }
    
    
    


    
  }
  
  getDefaultRouter() {
    return this.__defaultRouter;
  }
  
  getController(name) {
    return this.__controller[name];
  }
  
  loadRouters() {
    try {
      let routers = {};
      readdir.readSync(`${this.getProjectPath()}/${ROUTERS_PATH}`).map(routerFile => {
        if(routerFile.indexOf('.js')>0) {
          let routerName = routerFile.substr(0, routerFile.length-9);
          routers[routerName] = require(`${this.getProjectPath()}/${ROUTERS_PATH}${routerFile}`).default;
        }
      });
      return routers;
    } catch(e) {
      throw e;
    }
  }
  
  loadController() {
    try {
      let controller = {};
      readdir.readSync(`${this.getProjectPath()}/${Controller_PATH}`).map(controllerFile => {
        if(controllerFile.indexOf('Controller.js')>0) {
          let cntrlName = controllerFile.substr(0, controllerFile.length-13);
          let controllerObj = new (require(`${this.getProjectPath()}/${Controller_PATH}${controllerFile}`).default)( { app: this });
          controllerObj.setViewDirectory(path.resolve(this.getProjectPath(), 'Views'));
          controllerObj.setProjectDirectory(this.getProjectPath());
          controllerObj.setComponentDirectory(path.resolve(this.getProjectPath(), 'Components'));
          controllerObj.setContainerDirectory(path.resolve(this.getProjectPath(), 'Containers'));
          controller[cntrlName] = controllerObj
        }
      });
      return controller;
    } catch(e) {
      throw e;
    }
  }
  createRouter(name, props) {
    return new (this.__routers[name])(props);
  }
  
  getProjectPath() {
    return this.__props.projectPath;
  }
  
  getEnvironment() {
    return this.__environment;
  }
  
  loadEnvironment(name) {
    try {
      return require(`${this.getProjectPath()}/${ENVIRONMENT_PATH}${name}`).default;
    } catch(e) {
      throw e;
    }
  }
  
  
  start() {
    
    this.__expressApp.use('/public', express.static(`${this.getProjectPath()}/public`))
    
    this.__expressApp.all("*", (req, res) => {
      let matchResult = this.getDefaultRouter().match(req);
      if(matchResult) {        
        matchResult.route.renderAction(req, res, matchResult).then(actionContext => {
          try {
            actionContext.getResponse().respond(req, res);
          } catch(e) {
            res.send('Error: ' + String(e));
          }
        }).catch(e => {
          req.query = {
            error: e,
            controllerName: matchResult.route.getControllerName(),
            actionName: matchResult.route.getActionName()
          }
          
          this.getController('__defaultErrorController')
              .renderAction('actionError', req, res)
              .then(actionContext => {
                try {
                  actionContext.getResponse().respond(req, res);
                } catch(e) {
                  res.send('[1] Internal Server Error: ' + String(e));
                }
              })
              .catch(e => {
                res.send('[2] Internal Server Error: ' + String(e));
          	  })
        });
        
        
        
      } else {        
        this.getController('__defaultErrorController').renderAction('noRoute', req, res).then(actionContext => {
          try {
            actionContext.getResponse().respond(req, res);
          } catch(e) {
            res.send('Internal Server Error: ' + String(e));
          }
        }).catch(e => {
          console.log('renderedError', e);
        });
      }
    })

    this.__expressApp.listen(this.getEnvironment().server.port, () => {
      console.log(`Server started: ${process.env.NODE_ENV}`);
      console.log('Project Path: ', this.getProjectPath());
      console.log('Port: ', this.getEnvironment().server.port);
    })
  }
  
}

==> yahoi-0.1.1.tgz: package/src/lib/Server.js <==
import './conditional-babel-polyfill';
import express from 'express';
import readdir from 'readdir';
import bodyParser from 'body-parser';
import cookieParser from 'cookie-parser';
import compression from 'compression';
const ENVIRONMENT_PATH = "Environments/";
const ROUTERS_PATH = "Routing/";
const Controller_PATH = "Controller/";

import path from 'path';
import ErrorController from './../Controller/ErrorController';



export default class Server {
  
  constructor(props) {

    this.__props = props;
    this.__environment = this.loadEnvironment(props.env);
    this.__controller = this.loadController(props.env);


    // Default Error Controller
    let defaultErrorController =  new ErrorController({ app: this } );
    defaultErrorController.setViewDirectory(path.resolve(__dirname, '..', 'Views'));
    defaultErrorController.setProjectDirectory(path.resolve(__dirname, '..'));
    defaultErrorController.setComponentDirectory(path.resolve(__dirname, '..', 'Components'));
    defaultErrorController.setContainerDirectory(path.resolve(__dirname, '..', 'Containers'));
    this.__controller['__defaultErrorController'] = defaultErrorController;

    this.__routers = this.loadRouters(props.env);
    this.__expressApp = express();
    this.__expressApp.use(bodyParser.json())
    this.__expressApp.use(cookieParser())
   
    
   
    this.getController = this.getController.bind(this);

    this.__defaultRouter = new (this.__routers['Default'])({ app: this });

    if(typeof(process.env.NODE_ENV)!='undefined' && process.env.NODE_ENV=='development') {
      // Development
      let enableHmrMidWare = require('./dev/expressMiddleware.js');
      enableHmrMidWare(this, this.__expressApp);
    } else {     
      // Production
      this.__expressApp.use(compression());
    }
    
    
    


    
  }
  
  getDefaultRouter() {
    return this.__defaultRouter;
  }
  
  getController(name) {
    return this.__controller[name];
  }
  
  loadRouters() {
    try {
      let routers = {};
      readdir.readSync(`${this.getProjectPath()}/${ROUTERS_PATH}`).map(routerFile => {
        if(routerFile.indexOf('.js')>0) {
          let routerName = routerFile.substr(0, routerFile.length-9);
          routers[routerName] = require(`${this.getProjectPath()}/${ROUTERS_PATH}${routerFile}`).default;
        }
      });
      return routers;
    } catch(e) {
      throw e;
    }
  }
  
  loadController() {
    try {
      let controller = {};
      readdir.readSync(`${this.getProjectPath()}/${Controller_PATH}`).map(controllerFile => {
        if(controllerFile.indexOf('Controller.js')>0) {
          let cntrlName = controllerFile.substr(0, controllerFile.length-13);
          let controllerObj = new (require(`${this.getProjectPath()}/${Controller_PATH}${controllerFile}`).default)( { app: this });
          controllerObj.setViewDirectory(path.resolve(this.getProjectPath(), 'Views'));
          controllerObj.setProjectDirectory(this.getProjectPath());
          controllerObj.setComponentDirectory(path.resolve(this.getProjectPath(), 'Components'));
          controllerObj.setContainerDirectory(path.resolve(this.getProjectPath(), 'Containers'));
          controller[cntrlName] = controllerObj
        }
      });
      return controller;
    } catch(e) {
      throw e;
    }
  }
  createRouter(name, props) {
    return new (this.__routers[name])(props);
  }
  
  getProjectPath() {
    return this.__props.projectPath;
  }
  
  getEnvironment() {
    return this.__environment;
  }
  
  loadEnvironment(name) {
    try {
      return require(`${this.getProjectPath()}/${ENVIRONMENT_PATH}${name}`).default;
    } catch(e) {
      throw e;
    }
  }
  
  
  start() {
    
    this.__expressApp.use('/Public', express.static(`${this.getProjectPath()}/Public`))
    
    this.__expressApp.all("*", (req, res) => {
      let matchResult = this.getDefaultRouter().match(req);
      if(matchResult) {        
        matchResult.route.renderAction(req, res, matchResult).then(actionContext => {
          try {
            actionContext.getResponse().respond(req, res);
          } catch(e) {
            res.send('Error: ' + String(e));
          }
        }).catch(e => {
          req.query = {
            error: e,
            controllerName: matchResult.route.getControllerName(),
            actionName: matchResult.route.getActionName()
          }
          
          this.getController('__defaultErrorController')
              .renderAction('actionError', req, res)
              .then(actionContext => {
                try {
                  actionContext.getResponse().respond(req, res);
                } catch(e) {
                  res.send('[1] Internal Server Error: ' + String(e));
                }
              })
              .catch(e => {
                res.send('[2] Internal Server Error: ' + String(e));
          	  })
        });
        
        
        
      } else {        
        this.getController('__defaultErrorController').renderAction('noRoute', req, res).then(actionContext => {
          try {
            actionContext.getResponse().respond(req, res);
          } catch(e) {
            res.send('Internal Server Error: ' + String(e));
          }
        }).catch(e => {
          console.log('renderedError', e);
        });
      }
    })

    this.__expressApp.listen(this.getEnvironment().server.port, () => {
      console.log(`Server started: ${process.env.NODE_ENV}`);
      console.log('Project Path: ', this.getProjectPath());
      console.log('Port: ', this.getEnvironment().server.port);
    })
  }
  
}
